##  Automations
Event | Description
---|---
AUTOMATION_TRIGGERED | A no-code automation is triggered. For more details, see [Creating an Automation with a Webhook Action](https://help.sap.com/docs/leanix/ea/automations-webhooks?locale=en-US&state=PRODUCTION&version=CLOUD "Send webhooks from automations to trigger external workflows.").


